"use client";
import { ImageBaseUrl } from "@/configs/api";
import { cn } from "@/lib/utils";
import { Icon } from "@iconify/react/dist/iconify.js";
import { Star } from "lucide-react";
import { useLocale, useTranslations } from "next-intl";
import Image from "next/image";
import { useState } from "react";
import { Badge } from "../ui/badge";


const ProjectDetails = ({ _project }: { _project: any }) => {
	const t = useTranslations();
	const locale = useLocale();
	const [selectedImage, setSelectedImage] = useState(_project?.thumbnail?.image_path);

	return (
		<div className="flex flex-col items-start justify-between p-24 gap-28 md:flex-row">
			<div className={cn("flex flex-[30%] flex-col gap-5")}>
				<h1 className="text-xl font-semibold text-custom-dark">{t("Project Details")}</h1>
				<p className="text-justify text-base text-[#3B3B3B]">
					{locale === "ar" ? _project?.description_ar : _project?.description_en}
				</p>
				<div className="flex flex-row gap-2">
					<h6 className="text-sm text-custom-dark-light mt-[3px]">
						{t("Rating")}:

					</h6>
					{Array.from({ length: 5 })?.map((_, i) => (
						<Star
							key={i}
							className={cn(
								"h-5 w-5",
								i < _project?.rating
									? "fill-[#F2C94C] text-[#F2C94C]"
									: "text-gray-300"
							)}
						/>
					))}
				</div>
				<div className="flex flex-row gap-2">
					<h6 className="text-sm text-custom-dark-light mt-[3px]">
						{t("Tags")}:

					</h6>
					{_project?.tags?.map((_tag: any) => (
						<Badge
							key={_tag?.id}
							variant="outline"
							className={cn(
								"rounded-full border-custom-primary-accent px-4 py-1.5 text-custom-primary-accent",
							)}
						>
							{locale === "ar" ? _tag?.ar_name : _tag?.en_name}
						</Badge>
					))}
				</div>

				<h1 className="text-xl mt-4 font-semibold text-custom-dark">{t("Project Goals")}</h1>
				<div className="grid gap-2">
					{Object.entries(_project?.goals || {}).map(([id, goal]: [string, any]) => (
						<div
							key={id}
							className="flex items-start justify-between gap-4"
						>
							<Icon icon="mdi:check-circle" className="w-6 h-6 text-custom-primary-accent" />
							<p className="flex-1 text-sm text-custom-dark">
								{locale === "ar" ? goal?.ar : goal?.en}
							</p>
						</div>
					))}
				</div>

				<h1 className="text-xl mt-4 font-semibold text-custom-dark">{t("Project investment")}</h1>
				<div className="grid gap-2">
					{Object.entries(_project?.investment_details || {}).map(([id, investment]: [string, any]) => (
						<div
							key={id}
							className="flex items-start justify-between gap-4"
						>
							<Icon icon="fluent:diamond-20-filled" className="w-6 h-6 text-custom-primary-accent" />
							<p className="flex-1 text-sm text-custom-dark">
								{locale === "ar" ? investment?.ar : investment?.en}
							</p>
						</div>
					))}
				</div>


				<h1 className="text-xl mt-4 font-semibold text-custom-dark">{t("Project components")}</h1>
				<div className="grid gap-2">
					{Object.entries(_project?.components || {}).map(([id, component]: [string, any]) => (
						<div
							key={id}
							className="flex items-start justify-between gap-4"
						>
							<Icon icon="hugeicons:pin" className="w-6 h-6 text-custom-primary-accent" />
							<p className="flex-1 text-sm text-custom-dark">
								{locale === "ar" ? component?.ar : component?.en}
							</p>
						</div>
					))}
				</div>

			</div>

			<div className="flex flex-col gap-4">
				<div className="relative aspect-square h-[540px] w-[540px] overflow-hidden rounded-lg bg-gray-100"
					style={{
						boxShadow: "0px 4px 4px 0px #00000040",
					}}
				>
					<Image
						src={ImageBaseUrl + selectedImage}
						alt={_project?.title_en}
						fill
						className="object-cover"
					/>
				</div>
				<div className="flex gap-2 overflow-x-auto pb-2">
					{_project?.images?.map((image: any) => (
						<div key={image?.id} className="h-[85px] w-auto">
							<Image
								src={ImageBaseUrl + image?.image_path}
								alt={image?.name}
								width={100}
								height={85}
								className={cn(
									"h-full w-auto cursor-pointer object-contain rounded-lg border-2 transition-all hover:opacity-80",
									selectedImage === image?.image_path ? "border-custom-primary-accent" : "border-gray-300"
								)}
								onClick={() => setSelectedImage(image?.image_path)}
							/>
						</div>
					))}
				</div>
			</div>
		</div>
	);
};

export default ProjectDetails;
